@@ -478,6 +478,11 @@ const char *oidc_cmd_provider_jwks_uri_refresh_interval_set(cmd_parms *cmd, void
 	return OIDC_CONFIG_DIR_RV(cmd, rv);
 }
 
+int oidc_cfg_jwks_uri_refresh_interval_get(const oidc_jwks_uri_t *jwks_uri) {
+	return jwks_uri->refresh_interval != OIDC_CONFIG_POS_INT_UNSET ? jwks_uri->refresh_interval
+								       : OIDC_DEFAULT_JWKS_REFRESH_INTERVAL;
+}
+
 int oidc_cfg_provider_jwks_uri_refresh_interval_get(oidc_provider_t *provider) {
 	return provider->jwks_uri.refresh_interval != OIDC_CONFIG_POS_INT_UNSET ? provider->jwks_uri.refresh_interval
 										: OIDC_DEFAULT_JWKS_REFRESH_INTERVAL;
@@ -492,7 +497,7 @@ const char *oidc_cfg_provider_jwks_uri_uri_get(oidc_provider_t *provider) {
 }
 
 const char *oidc_cfg_provider_jwks_uri_set(apr_pool_t *pool, oidc_provider_t *provider, const char *arg) {
-	const char *rv = oidc_cfg_parse_is_valid_url(pool, arg, "https");
+	const char *rv = oidc_cfg_parse_is_valid_http_url(pool, arg);
 	if (rv == NULL)
 		provider->jwks_uri.uri = apr_pstrdup(pool, arg);
 	return rv;
@@ -556,7 +561,7 @@ const char *oidc_cfg_provider_signed_jwks_uri_set(apr_pool_t *pool, oidc_provide
 	json_t *json = NULL;
 
 	if ((arg1 != NULL) && (_oidc_strcmp(arg1, "") != 0)) {
-		rv = oidc_cfg_parse_is_valid_url(pool, arg1, "https");
+		rv = oidc_cfg_parse_is_valid_http_url(pool, arg1);
 		if (rv != NULL)
 			goto end;
 		provider->jwks_uri.signed_uri = apr_pstrdup(pool, arg1);
